@@ -9,5 +9,8 @@ pub use get_exponent_bits::*;
 mod get_exponent_value;
 pub use get_exponent_value::*;
 
+mod ldexp;
+pub use ldexp::*;
+
 mod truncate;
 pub use truncate::*;
